@@ -533,7 +533,12 @@ static void initJavaSession(void)
 
 static void checkIntTimeType(void)
 {
+	#if (PGSQL_MAJOR_VER > 8)
+	const char* idt = GetConfigOption("integer_datetimes", true);
+	#else
 	const char* idt = GetConfigOption("integer_datetimes");
+	#endif
+
 	integerDateTimes = (strcmp(idt, "on") == 0);
 	elog(DEBUG1, integerDateTimes ? "Using integer_datetimes" : "Not using integer_datetimes");
 }
@@ -561,7 +566,13 @@ static void initializeJavaVM(void)
 			"Options sent to the JVM when it is created",
 			NULL,
 			&vmoptions,
+			#if (PGSQL_MAJOR_VER > 8 || (PGSQL_MAJOR_VER == 8 && PGSQL_MINOR_VER > 3))
+				NULL,
+			#endif
 			PGC_USERSET,
+			#if (PGSQL_MAJOR_VER > 8 || (PGSQL_MAJOR_VER == 8 && PGSQL_MINOR_VER > 3))
+				0,
+			#endif
 			NULL, NULL);
 	
 		DefineCustomStringVariable(
@@ -569,7 +580,13 @@ static void initializeJavaVM(void)
 			"Classpath used by the JVM",
 			NULL,
 			&classpath,
+			#if (PGSQL_MAJOR_VER > 8 || (PGSQL_MAJOR_VER == 8 && PGSQL_MINOR_VER > 3))
+				NULL,
+			#endif
 			PGC_USERSET,
+			#if (PGSQL_MAJOR_VER > 8 || (PGSQL_MAJOR_VER == 8 && PGSQL_MINOR_VER > 3))
+				0,
+			#endif
 			NULL, NULL);
 	
 		DefineCustomBoolVariable(
@@ -577,7 +594,13 @@ static void initializeJavaVM(void)
 			"Stop the backend to attach a debugger",
 			NULL,
 			&pljavaDebug,
+			#if (PGSQL_MAJOR_VER > 8 || (PGSQL_MAJOR_VER == 8 && PGSQL_MINOR_VER > 3))
+				false,
+			#endif
 			PGC_USERSET,
+			#if (PGSQL_MAJOR_VER > 8 || (PGSQL_MAJOR_VER == 8 && PGSQL_MINOR_VER > 3))
+				0,
+			#endif
 			NULL, NULL);
 	
 		DefineCustomIntVariable(
@@ -585,8 +608,14 @@ static void initializeJavaVM(void)
 			"Size of the prepared statement MRU cache",
 			NULL,
 			&statementCacheSize,
+			#if (PGSQL_MAJOR_VER > 8 || (PGSQL_MAJOR_VER == 8 && PGSQL_MINOR_VER > 3))
+				11,
+			#endif
 			0, 512,
 			PGC_USERSET,
+			#if (PGSQL_MAJOR_VER > 8 || (PGSQL_MAJOR_VER == 8 && PGSQL_MINOR_VER > 3))
+				0,
+			#endif
 			NULL, NULL);
 	
 		DefineCustomBoolVariable(
@@ -594,7 +623,13 @@ static void initializeJavaVM(void)
 			"If true, lingering savepoints will be released on function exit. If false, the will be rolled back",
 			NULL,
 			&pljavaReleaseLingeringSavepoints,
+			#if (PGSQL_MAJOR_VER > 8 || (PGSQL_MAJOR_VER == 8 && PGSQL_MINOR_VER > 3))
+				false,
+			#endif
 			PGC_USERSET,
+			#if (PGSQL_MAJOR_VER > 8 || (PGSQL_MAJOR_VER == 8 && PGSQL_MINOR_VER > 3))
+				0,
+			#endif
 			NULL, NULL);
 	
 		EmitWarningsOnPlaceholders("pljava");
@@ -775,7 +810,12 @@ JNICALL Java_org_postgresql_pljava_internal_Backend__1getConfigOption(JNIEnv* en
 	{
 		PG_TRY();
 		{
+			#if (PGSQL_MAJOR_VER > 8)
+			const char* value = GetConfigOption(key, true);
+			#else
 			const char* value = GetConfigOption(key);
+			#endif
+			
 			pfree(key);
 			if(value != 0)
 				result = String_createJavaStringFromNTS(value);
